## Header section ## ----
rm(list=(ls()))
setwd("C:/cygwin64/home/Andrew/Dropbox/shared_AL/fuji/Caroline_heatmaps/")
require(gplots)

## Data import ## ----
membrane <- read.csv("membrane.csv", stringsAsFactors=F)
soluble <- read.csv("soluble.csv", stringsAsFactors=F)
secreted <- read.csv("secreted.csv", stringsAsFactors=F)

collected<-rbind(membrane[-1,],secreted[-1,],soluble[-1,])
write.csv(sort(unique(collected[,1])),"reference_prots.csv")

## Functions ## ----
# trim.phenyx ----
trim.phenyx <- function(x){
  input.length <- dim(x)[1]
  x.mod <- x[2:input.length,27:34] 
  colnames(x.mod) <- lapply(x[1,27:34],as.character)
  rownames(x.mod) <- lapply(x[2:input.length,1],as.character)
  catch <- c()
  
  for(i in 1:dim(x.mod)[1]){
    for(j in 1:dim(x.mod)[2]){
      if(x.mod[i,j]=="Indeterminate"){
        catch <- c(catch,i)
        break
      }
    }
  }
  x <- x.mod[-catch,]
  x <- data.matrix(x)
}

## Clusters and dendrograms ----
# Run a sum of squares plot using k-means to determine a number of clusters to take
a <- trim.phenyx(membrane)
wss <- (nrow(a)-1)*sum(apply(a,2,var))
for (i in 2:20) wss[i] <- sum(kmeans(a,centers=i)$withinss)

plot(1:20, wss, type="b", 
     xlab="Number of Clusters",
     ylab="Within groups sum of squares")

cutpoint <- 8 #selected number of clusters
abline(v=cutpoint, col="grey60")

# Generate k-means grouped data based on the previous graph
hc <- hclust(dist(a), "ward.D")
memb <- cutree(hc, k = cutpoint) #Where k = number of desired clusters
write.csv(memb,"clusters.csv")

sidecols <- memb
for(i in 1:cutpoint){
  sidecols[sidecols==i] <- c("green","red","blue","purple","cyan","yellow","grey60","black")[i]
}
sidecols <- as.character(sidecols)

pdf("test_heatmapClust.pdf")
heatmap.2(trim.phenyx(membrane), 
          main="Membrane Fraction",
          col=redgreen(75), 
          scale="row", 
          RowSideColors=sidecols,
          margins=c(6,11), 
          Rowv=as.dendrogram(hc), 
          labRow = F, 
          key = F, 
          density.info="none",
          trace="none",
          cexCol=1,  
          srtCol=45)
dev.off()
